pub struct InjectExecOptions {
pub isolate_stdio: bool,
}Expand description
Execution options for process launch behavior.
Fields
isolate_stdio: boolWhen true, child stdio is detached from parent stdio. Useful for MCP stdio transports where child output must not corrupt JSON-RPC frames.